{% extends 'doc/es/base.html' %} {% load static %} {% block content %} {% verbatim %}

# CRUD

    from Book.models import Author, Book
    from blitz_work.blitzcrud import BlitzCRUD

    class BookCRUD(BlitzCRUD):
        show_title = True
        show_caption = False
        caption_is_title = True
        extend_template = "base.html"
        data = Book

Blitz Work provee muchas opciones para facilitar su uso y vizualización.

    class BlitzCRUD(View):
        template_name = "blitz_base_crud.html"
        extend_template = "blitz_base_offline.html"
        table_template = "blitz_crud_table.html"
        create_template = "blitz_crud_create.html"
        update_template = "blitz_crud_update.html"
        delete_template = "blitz_crud_delete.html"
        detail_template = "blitz_crud_detail.html"
        model = None
        paginate_by = 20
        title = None
        form = None
        formset = None
        show_caption = True
        create_title = "Create"
        show_title = True
        caption_is_title = False
        concat_function = default_concatenation
        exclude = ['id', ]
        dark_mode_switch_label = None
        delete_messages = {"success": "Element deleted",
                           "error": "Error on delete"}
        delete_title = "Delete"
        update_title = "Edit"
        detail_title = "Detail"
        delete_text = "The following elements will be deleted, do you want to delete them?"
        crud_buttons = {"add": "Add", "create": "Create", "details": "Details", "update": "Update",
                        "edit": "Edit", "delete": "Delete", "cancel": "Cancel", "return": "Return", "search": "Search"}
        allow_anonimous_in_debug = True

#### Variables de plantillas.

- ##### template_name

  Plantilla principal. Esta es la plantilla que renderiza la vista de lista. Debe contener los botones de búsqueda, añadir, editar, eliminar, cancelar y detalles así como la tabla de datos.

- ##### extend_template

  Esta es la plantilla que se utilizaran como base todas las vistas de no ser modificadas. Su valor será el de la variable (extend_template) en las plantillas que provee Blitz Work

- ##### table_template

  Esta es la plantilla que se utilizará para mostrar la tabla en la vista de lista de no ser modificada.

- ##### create_template

  Esta es la plantilla que se utilizará para la vista de crear.

- ##### update_template

  Esta es la plantilla que se utilizará para la vista de actualizar.

- ##### delete_template

  Esta es la plantilla que se utilizará para la vista de eliminar.

- ##### detail_template

  Esta es la plantilla que se utilizará para la vista de detalles.

#### Variables de datos y lista.

- ##### model

  Especifica el modelo que utilizara el CRUD.

- ##### paginate_by

  Especifica la cantidad de filas por pagina en el CRUD.

- ##### form

  Especifica el formulario que se utilizara para la vista de añadir en CRUD. De no ser especificado Blitz Work creará un formulario por defecto con todos los campos del modelo.

- ##### formset

  Especifica el conjunto de formulario que se utilizara para la vista de editar y detalles en CRUD. De no ser especicficado Blitz Work creará uno por defecto con todos los campos del modelo. (Blitz Work provee edición múltiple y vista de detalles multiple, es por esto que es necesario.).

- ##### concat_function

  Especifica la función que se utilizara para concatenar los elementos en una relación (m2m), en la vista de lista. De no ser especificado Blitz Work utilizará la siguiente función.

      def default_concatenation(self, list):
          """
          Default concatenation function
          """
          return ", ".join(list)

- ##### exclude

  Especifica los campos que se excluirán del modelo en la tabla.

- ##### allow_anonimous_in_debug

  Blitz Work comprueba si el usuario posee permisos para cada una de las vistas y acciones. Esta variable permite a un usuario sin autenticar saltar las restricciones. Esto es solo si el proyecto actual esta en modo DEBUG.

#### Variables de texto y títulos.

- ##### title

  Especifica el título de la vista de lista en el CRUD.

- ##### create_title

  Especifica el título de la vista de creación en el CRUD.

- ##### update_title

  Especifica el título de la vista de actulalización en el CRUD.

- ##### detail_title

  Especifica el título de la vista de detalles en el CRUD.

- ##### delete_title

  Especifica el título de la vista de eliminación en el CRUD.

- ##### delete_text

  Especifica el mensaje de la vista de eliminación en el CRUD.

- ##### delete_messages

  Especifica el texto de los mensajes de eliminación del CRUD.

- ##### crud_buttons

  Especifica el texto de los botones del CRUD.

- ##### show_title

  Especifica si se muestra el título en la vista de lista del CRUD.

- ##### show_caption

  Especifica si se muestra la descripción de la tabla del CRUD. Su valor coresponde al del verbose_name del modelo.

- ##### caption_is_title

  Especifica si se utilizará como título el verbose_name del modelo.

- ##### dark_mode_switch_label

  Especifica texto del switch de modo oscuro.

{% endverbatim %} {% endblock content %}